@@ -16,7 +16,9 @@ use GD::Polygon;
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-$VERSION = '2.56';
+$VERSION = '2.57';
+our $XS_VERSION = $VERSION;
+$VERSION = eval $VERSION;
 
 @ISA = qw(Exporter DynaLoader);
 # Items to export into callers namespace by default. Note: do not export
@@ -460,6 +462,8 @@ support.
 NOTE: The libgd library is unable to read certain XPM files, returning
 an all-black image instead.
 
+=back
+
 =head1 GD::Image Methods
 
 Once a GD::Image object is created, you can draw with it, copy it, and
@@ -472,6 +476,8 @@ a file.
 The following methods convert the internal drawing format into
 standard output file formats.
 
+=over
+
 =item B<$pngdata = $image-E<gt>png([$compression_level])>
 
 This returns the image data in PNG format.  You can then print it,
@@ -692,6 +698,16 @@ Example:
 This returns a list containing the red, green and blue components of
 the specified color index.
 
+Example:
+
+	@RGB = $myImage->rgb($peachy);
+
+
+=item B<($alpha) = $image-E<gt>alpha($index)>
+
+This returns an item containing the alpha component of the specified
+color index.
+
 Example:
 
 	@RGB = $myImage->rgb($peachy);
@@ -1756,6 +1772,20 @@ These return the width and height of the font.
 
 =back
 
+=head1 Helper Functions
+
+=over
+
+=item GD::LIBGD_VERSION
+
+Returns the string of the libgd VERSION, like "2.2.4".
+
+=item GD::LIBGD_VERSION
+
+Returns the string of the libgd VERSION, like "2.2.4".
+
+=back
+
 =head1 Obtaining the C-language version of gd
 
 libgd, the C-language version of gd, can be obtained at URL
